@@ -50,16 +50,30 @@ public:
     virtual ~BlueDevilDaemon();
 
 public Q_SLOTS:
+    /**
+     * Returns whether the daemon is in online mode (eg. Bluez services are
+     * running and we have usable adapter)
+     */
     Q_SCRIPTABLE bool isOnline();
 
     /**
-     * This slot will return a list of devices made of: configured and discovered devices.
-     * Going deeper, the first time that this slot is called a discovery of X seconds will start
-     * Then if this slot is consulted again it will return configured and discovered device. Once
-     * the discovery ends it won't start a new discovery until N seconds pass.
+     * Returns QMap<Address, DeviceInfo> with all known devices
      */
-    Q_SCRIPTABLE QMapDeviceInfo knownDevices();
+    Q_SCRIPTABLE QMapDeviceInfo allDevices();
 
+    /**
+     * Returns DeviceInfo for one device.
+     */
+    Q_SCRIPTABLE DeviceInfo device(const QString &address);
+
+    /**
+     * Starts discovery for timeout miliseconds (0 = forever)
+     */
+    Q_SCRIPTABLE void startDiscovering(quint32 timeout);
+
+    /**
+     * Stops discovery (if it was previously started)
+     */
     Q_SCRIPTABLE void stopDiscovering();
 
 private:
@@ -82,6 +96,9 @@ private Q_SLOTS:
      */
     void usableAdapterChanged(Adapter *adapter);
 
+    void adapterAdded(Adapter *adapter);
+    void adapterRemoved(Adapter *adapter);
+
     /**
      * When the agent is released this is called to unload it
      */
@@ -97,7 +114,11 @@ private:
     void executeMonolithic();
     void killMonolithic();
 
-    DeviceInfo deviceToInfo (Device *const device) const;
+    void saveAdaptersState();
+    void restoreAdaptersState();
+    void restoreAdapterState(Adapter *adapter);
+
+    DeviceInfo deviceToInfo(Device *const device) const;
 
 private:
     struct Private;
